@@ -59,21 +59,23 @@ use Data::Printer::Filter::CODE;
 use Data::Printer::Filter::GenericClass;
 
 # create our basic accessors:
-foreach my $method_name (qw(
+my @method_names =qw(
     name show_tainted show_unicode show_readonly show_lvalue show_refcount
     show_memsize memsize_unit print_escapes scalar_quotes escape_chars
     caller_info caller_message string_max string_overflow string_preserve
     array_max array_overflow array_preserve hash_max hash_overflow
     hash_preserve ignore_keys unicode_charnames colored theme show_weak
     max_depth index separator end_separator class_method class hash_separator
-    align_hash sort_keys quote_keys deparse return_value
-)) {
+    align_hash sort_keys quote_keys deparse return_value show_dualvar
+);
+foreach my $method_name (@method_names) {
     no strict 'refs';
     *{__PACKAGE__ . "::$method_name"} = sub {
         $_[0]->{$method_name} = $_[1] if @_ > 1;
         return $_[0]->{$method_name};
     }
 }
+sub extra_config { $_[0]->{extra_config} }
 
 sub current_depth { $_[0]->{_depth}   }
 sub indent        { $_[0]->{_depth}++ }
@@ -197,6 +199,7 @@ sub _init {
                              'pass',
                              [qw(pass dump void)]
                        );
+    $self->{'show_dualvar'} = Data::Printer::Common::_fetch_scalar_or_default($props, 'show_dualvar', 1);
 
 
     if (exists $props->{as}) {
@@ -213,6 +216,14 @@ sub _init {
     $self->_load_filters($props);
     $self->output($props->{output} || 'stderr');
 
+    my %extra_config;
+    my %core_options = map { $_ => 1 }
+        (@method_names, qw(as multiline output colors filters));
+    foreach my $key (keys %$props) {
+        $extra_config{$key} = $props->{$key} unless exists $core_options{$key};
+    }
+    $self->{extra_config} = \%extra_config;
+
     return $self;
 }
 
@@ -444,8 +455,6 @@ sub _filters_for_data {
     my $ref_kind = Scalar::Util::reftype($data);
     $ref_kind = 'SCALAR' unless $ref_kind;
 
-    # globs don't play nice
-    $ref_kind = 'GLOB' if "$ref_kind" =~ /GLOB\([^()]+\)$/;
     # Huh. ref() returns 'Regexp' but reftype() returns 'REGEXP'
     $ref_kind = 'Regexp' if $ref_kind eq 'REGEXP';
 
@@ -661,15 +670,22 @@ sub write_label {
 }
 
 sub maybe_colorize {
-    my ($self, $output, $color_type, $end_color) = @_;
+    my ($self, $output, $color_type, $default_color, $end_color) = @_;
 
-    if ($self->color_level) {
-        $output = $self->theme->sgr_color_for($color_type)
-             . $output
-             . (defined $end_color
-                 ? $self->theme->sgr_color_for($end_color)
-                 : $self->theme->color_reset
-             );
+    if ($self->color_level && defined $color_type) {
+        my $theme = $self->theme;
+        my $sgr_color = $theme->sgr_color_for($color_type);
+        if (!defined $sgr_color && defined $default_color) {
+            $sgr_color = $theme->_parse_color($default_color);
+        }
+        if ($sgr_color) {
+            $output = $sgr_color
+                . $output
+                . (defined $end_color
+                    ? $theme->sgr_color_for($end_color)
+                    : $theme->color_reset
+                );
+        }
     }
     return $output;
 }
